@@ -12,7 +12,6 @@ package OP::Redefines;
 #
 
 $Carp::Internal{"OP::Redefines"}++;
-$Carp::Internal{"Perl6::Subs"}++;
 
 do {
   #
@@ -34,25 +33,6 @@ do {
   }
 };
 
-do {
-  #
-  # Prettify exceptions
-  #
-  no strict "refs";
-  no warnings "redefine";
-
-  *{"Perl6::Subs::_error"} = sub {
-    my $sub = (caller(0))[3];
-    my ($c_file, $c_line) = (caller(0))[1, 2];
-
-    my $msg = join '', @_;
-    $msg .= " in call to $sub" unless $sub =~ /^\(/;
-    $msg .= " at $c_file line $c_line";
-
-    throw OP::InvalidArgument( $msg );
-  }
-};
-
 1;
 __END__
 =pod
